@@ -33,6 +33,49 @@ def st_project_selector(title: str = None):
         st.metric(label=f"Active project ID: {st.session_state['project_id']}",
                   value=f"{st.session_state['project_name']}")
 
+
+def st_system_generator_selector():
+    """A function which adds a system generator selector to the top of the page.
+    A system generator is the stored as part of the project in the backend.
+
+    Suitable to be used in conjunction with st_project_selector().
+    """
+    # check if the project is set and exit without doing anything if not
+    if 'project_id' not in st.session_state or st.session_state['project_id'] is None:
+        return
+
+    # get the list of system generators for the current project
+    status_code, system_generators = _backend_GET(f"/projects/{st.session_state['project_id']}/sysgen")
+
+    # if successful display a selector for the system generators based on their IDs and names
+    if status_code == 200:
+        selected_sysgen = st.selectbox("System Generator",
+                                            [(sysgen["id"], sysgen["description"])
+                                             for sysgen in system_generators],
+                                            index=None,
+                                            placeholder="Select a system generator",
+                                            format_func=lambda x: f"{x[1]}")
+
+        if selected_sysgen is not None:
+            st.session_state["sysgen_id"] = int(selected_sysgen[0])
+            st.session_state["sysgen_description"] = selected_sysgen[1]
+    else:
+        st.error(f"Error while loading system generators: {system_generators}")
+
+    # After selecting a system generator, extract and present the generated designs from system_generators with the ID system_generators_id
+    if 'sysgen_id' in st.session_state:
+        status_code, system_generator = _backend_GET(f"/projects/{st.session_state['project_id']}/sysgen/{st.session_state['sysgen_id']}/")
+        if status_code == 200:
+            st.session_state["system_generator"] = system_generator
+            st.session_state["generated_designs"] = system_generator.get("generated_designs")
+        else:
+            st.error(f"Error while loading generated designs: {system_generator}")
+
+    # display the selected system generator
+    if 'sysgen_description' in st.session_state:
+        st.metric(label=f"Selected System Generator (ID: {st.session_state['sysgen_id']})",
+                  value=st.session_state["sysgen_description"])
+
 def st_generated_design_selector():
     """A function which adds a generated design selector to the top of the page.
     A generated design is the stored as part of the project in the backend.
